@@ -19,6 +19,7 @@ c 2017-11-29 RBS: Removed the enhancement of uhalf, uhalf should not be
 c                 enhanced
 c 2018-02-22 RBS: Changed the definition of vt to include the motion of
 c                 both the anode and cathode plasmas
+c 2019-01-21 RBS: Gap_1 removed from the real declaration. Not used.
 c
 c  Core routine based on sdiode_model
 c
@@ -75,7 +76,7 @@ c
 c Define internal variables
 c
       real       area, beta, circ, circ_i, e_cathode, efield,
-     &           gamma, gap, gap_d, gap_1, g_log, gap_time, perveance,
+     &           gamma, gap, gap_d, g_log, gap_time, perveance,
      &           tanode, tcathode, uhalf,
      &           velocity, voltlast, volthalf
 
