@@ -55,7 +55,7 @@ c
 c
 c-----Passed variables
 c
-      character inpfile*80
+      character inpfile*(*)
 c
       integer clen
 c
@@ -95,7 +95,7 @@ c Error found when opening the data file, so print a message and stop.
 c
  999  continue
       write(6,'(A)')
-     & ' ### Unable to open the input file, exection halted.'
+     & ' ### GetEnvVr - Unable to open the input file, exection halted.'
 
       stop
       end
