@@ -25,8 +25,8 @@ c                 lines 145,146
 c 2015-12-25 YG:  a, am_band, and rhs_band are defined in zdemwork.h.
 C                 Also removed parameter a in the screamermatrix.
 c 2016-03-16 RBS: Cleaned up the write formats.
-c
-c
+c 2019-10-19 YG:  Parallel solver bandPRLsolver, residual PRL_Res,
+c                 a_prl is defined in zdemwork.h. line 58-62, 132-146
 c ----------------------------------------------------------------------
 c
 c Purpose: This subroutines performs the calculations. 
@@ -54,7 +54,12 @@ c Define internal variables
 c
 
       integer iptold, iptime, jdiv, nk, nzz
-
+      
+c
+c Auxiliary variables for parallel solver and residual calculation
+c
+      integer ny,ny1,nrow
+      real*8  eps, ep, ep1
 c
 c Include file with version string
 c
@@ -124,30 +129,63 @@ c
 c We define max_am in common as the passed maximum dimension of the
 c am_band matrix and b vector
 c
-      nk = ntot*2
-
-      call bandmatrix(a,am_band,rhs_band,nk,nr,
-     &                indexb,nadd_array,nb,topbranch,max_am)
+c ******* this is the sequential solver part which is not used ******
 
+c      nk = ntot*2
 c
+c      call bandmatrix(a,am_band,rhs_band,nk,nr,
+c     &                indexb,nadd_array,nb,topbranch,max_am)
+
+C ******* Parallel solver ******
+C Use the Screamer format to execute the parallel solution of the
+C system.
+
+      call bandPRLsolver(a,a_prl,nr,indexb,nadd_array,nb,topbranch)
+
+c ****** This is a sequential solver which is not used in parallel *****
 c The next subroutine solves the linear system using modified Gaussian
 c elemination procedure based on the highly structured sparce matrix
 c obtained on the previous step. The solution vector is in the rhs_band
 c vector.
 c
-      call solvermdgauss(am_band,rhs_band,nk,max_am,nadd_array,nb,nr)
+c      call solvermdgauss(am_band,rhs_band,nk,max_am,nadd_array,nb,nr)
 c
 c  Prepare to find voltage and curent at each node.
 c
+      k=2
+      nrow = 7
+      eps = 0
+
       do ib = 1, nb
         nzz  = nadd_array(ib) * k
         nrx  = nr(ib)
         do i = 1, nrx
-          j          = (i-1)*2 + 1 + nzz
-          vn(i,ib)   = real(rhs_band(j))
-          zirn(i,ib) = real(rhs_band(j+1))
+          j   = (i-1)*2 + 1 + nzz
+          ny  = nrow*(j-1)
+          ny1 = ny   + nrow
+
+          vn(i,ib)   = real(a_prl(ny + 6))
+          zirn(i,ib) = real(a_prl(ny1 + 6))
+c
+c Calculate the residual at every row of the system
+c it is included to check the accuracy of the parallel solver
+c
+c            call PRL_Res(ib,i,nrx,a,a_prl,indexb,nadd_array,nb,
+c     &                   topbranch,ep,ep1)
+c
+c            ep = max(abs(ep), abs(ep1))
+c            eps = max(eps, ep)
+
           end do
         end do
+C
+C the maximum residual norm - eps, included to check the solver
+C accuracy
+C
+c        if(eps.gt. 10E-3) then
+c            print *,' eps = ', eps
+c        end if
+C
 c
       call energy_checks
 c
