@@ -14,6 +14,10 @@ c 2015-06-23 RBS: Indexout initialized, zdemfmt.h removed as not needed
 c 2017-02-24 RBS: Changed the lblout definition from using currline to
 c                 using currline_lc
 c 2018-02-22 RBS: Added a new output parameter closs in Zflow/MITL
+c 2019-01-27 RBS: Added scale option for time_steps test
+c 2019_01-27 RBS: Added scale keyword test, and inputted scale_out
+c 2019-04-05 RBS: Added TXT output option, changed log file to write -
+c                 TXT output requested, UFO call will be deprecated
 c---------------------------------------------------------------------
 
       subroutine readscreameroutputs(status)
@@ -42,8 +46,8 @@ c
 c ***** Time flag parameters ******
 c
 
-      integer time_flag, half_step,     whole_step
-      parameter         (half_step = 1, whole_step = 2)
+      integer half_step, whole_step, scale, time_flag, scale_flag
+      parameter (half_step = 1, whole_step = 2, scale = 3)
 
 c
       status = 0
@@ -51,7 +55,12 @@ c
 c Initialize internal variables
 c
       indexout = 0
+      scale_flag = 0
+      tscale = 1.0
 
+c
+c If keyword (first field) is an output request then
+c
       if ((keyword .eq. k_pltpts) .or.
      &         (keyword .eq. k_prtpts) .or.
      &         (keyword .eq. k_filpts) .or.
@@ -60,7 +69,9 @@ c
      &         (keyword .eq. k_idrpts) .or.
      &         (keyword .eq. k_pffpts) .or.
      &         (keyword .eq. k_csvpts) .or.
-     &         (keyword .eq. k_sfcpts)) then
+     &         (keyword .eq. k_sfcpts) .or.
+     &         (keyword .eq. k_txtpts)) then
+
 c This is an output request.     
 c Save this keyword and set the keyword for the type of output variable.
 c
@@ -629,23 +640,22 @@ c
 c
 c --- KWS Measure Zflow and Cathode Current Block ---
 c
-      else if (keyword .eq. k_icathode) then
-        labelout = 'Cathode Current'
-        labelplt = 'I Cathode'
-        labelidr = 'ICA'
-        indextyp = ip_icathode
+        else if (keyword .eq. k_icathode) then
+          labelout = 'Cathode Current'
+          labelplt = 'I Cathode'
+          labelidr = 'ICA'
+          indextyp = ip_icathode
 c
-      else if (keyword .eq. k_iplasma) then
-        labelout = 'Plasma Current'
-        labelplt = 'I Plasma'
-        labelidr = 'IPL'
-        indextyp = ip_iplasma
-c
-      else if (keyword .eq. k_zot) then
-        labelout = 'Zflow of T'
-        labelplt = 'Zflow of T'
-        labelidr = 'ZOT'
-        indextyp = ip_zot
+        else if (keyword .eq. k_iplasma) then
+          labelout = 'Plasma Current'
+          labelplt = 'I Plasma'
+          labelidr = 'IPL'
+          indextyp = ip_iplasma
+        else if (keyword .eq. k_zot) then
+          labelout = 'Zflow of T'
+          labelplt = 'Zflow of T'
+          labelidr = 'ZOT'
+          indextyp = ip_zot
 c
 c -----------------------------------
 c
@@ -721,7 +731,7 @@ c
           indextyp = ip_pline
         else
           call print_bad_line (currline, nlines, numerr)
-        status=305
+        status = 305
         return
         end if
 c
@@ -731,25 +741,36 @@ c them to 0 and end time, respectively. Here we have the option that if
 c no time_flag has been entered tstart an tstop can still be entered
 c
 c First field is output type, second field is output parameter
-c Third field is the (time_flag_ option
+c Third field is the (time_flag_ or scale option
+
         jj = 3
         call strip (field(jj), istart, iend)
         if (istart .ne. notext) then
+c Try to read a number, else err
           call text_to_real (field(jj), tstart, flag)
+c If text_to_real gives an error field(jj) must be characters
           if (flag .eq. err) then
              flag = noerr
              keyword = field(jj)(1:keyword_len)
-c could check for a third keyword - scale
-c else if keyword .eq. k_scale) then
+c
+c Check if the third field is an allowed character
+c
              if (keyword .eq. k_wholestep) then
                 time_flag = whole_step
-             else
+             else if (keyword .eq. k_halfstep) then
                 time_flag = half_step
-             endif
+             else if (keyword .eq. k_scale) then
+                scale_flag = scale
+             end if
+
+c Look at the contents of the fourth field and strip blanks
              jj = jj + 1
-             call strip (field(jj), istart, iend)
-c enter scale factor here when keyword is scale
-             if (istart .ne. notext) then
+               call strip (field(jj), istart, iend)
+c
+c If there is an entry in the fourth field and the entry is not scale
+c  read in tstart and tstop
+
+             if ((istart .ne. notext) .and. (scale_flag .ne. 3)) then
                 call text_to_real (field(jj), tstart, flag)
                 jj = jj + 1
                 call text_to_real (field(jj), tstop, flag2)
@@ -759,8 +780,10 @@ c enter scale factor here when keyword is scale
                 flag = noerr
                 flag2 = noerr
              endif
+
           else
              jj = jj + 1
+
              if ((keywordsave .ne. k_idrpts) .and.
      +           (keywordsave .ne. k_sfcpts) .and. 
      +           (keywordsave .ne. k_pffpts))        then
@@ -768,9 +791,12 @@ c enter scale factor here when keyword is scale
              else
                time_flag = whole_step
              endif
+
              call text_to_real (field(jj), tstop,  flag2)
           endif
+
         else
+
           if ((keywordsave .ne. k_idrpts) .and.
      +        (keywordsave .ne. k_sfcpts) .and. 
      +        (keywordsave .ne. k_pffpts))        then
@@ -778,17 +804,20 @@ c enter scale factor here when keyword is scale
           else
             time_flag = whole_step
           endif
+
           tstart = 0.0
           tstop  = tmax
           flag   = noerr
           flag2  = noerr
         end if
+
 c
 c Test to see if Ymin and Ymax have been entered, if not, then set them
 c both to zero to enable automatic scaling when plotting.
 c
         jj = jj + 1
         call strip (field(jj), istart, iend)
+
         if (istart .ne. notext) then
           call text_to_real (field(jj), ymin, flag3)
           jj = jj + 1
@@ -799,17 +828,32 @@ c
           flag3 = noerr
           flag4 = noerr
         end if
+
         if ((flag+flag2+flag3+flag4) .ne. noerr) then
           call print_bad_line (currline, nlines, numerr)
-        status=305
-        return
+          status = 305
+          return
         end if
-
+c
+c increment number of output calls and limit to maxout
+c
         numout = numout + 1
         if (numout .gt. maxout) then
            status = 1000
            return
         end if
+c
+c Read in the scale factor only if scale_flag = scale
+c
+        scale_out(numout) = tscale
+        if ( scale_flag .eq. scale ) then
+          call text_to_real (field(4), tscale, flag2)
+          scale_out(numout) = tscale
+        end if
+c        print '(i2,2x,1pe10.3,1pe10.3)',numout,tscale,scale_out(numout)
+c
+c Write log file info for 
+c
         if (keywordsave .eq. k_pltpts) then
           numplt = numplt + 1
           write(9,
@@ -847,7 +891,16 @@ c
         else if (keywordsave .eq. k_ufopts) then
           numufo = numufo + 1
           write(9,'(A,i3,A,a23)')
-     &     ' UFO Output Request for block ',nublks,
+     &     ' TXT Output Request for block ',nublks,
+     &     '.    Variable: ',labelout
+          iouttype(numout) = oufo
+          indexout         = ip_ufopts
+          tstart           = 0.0
+          tstop            = tmax
+        else if (keywordsave .eq. k_txtpts) then
+          numufo = numufo + 1
+          write(9,'(A,i3,A,a23)')
+     &     ' TXT Output Request for block ',nublks,
      &     '.    Variable: ',labelout
           iouttype(numout) = oufo
           indexout         = ip_ufopts
@@ -891,23 +944,22 @@ c
           tstop            = tmax
         end if
 c
-c Set so UFO and CSV are always half time steps.
+c Set so UFO, TXT, and CSV are always half time steps.
 c
         if ((time_flag .eq. whole_step) .and.
      &      (keywordsave .ne. k_ufopts) .and.
+     &      (keywordsave .ne. k_txtpts) .and.
      &      (keywordsave .ne. k_csvpts)) then
-           write(9,'(A)')
-     &      '  Values on the whole time step will be used.'
+          write(9,'(A)') '  Values on the whole time step will be used.'
 c
 c kls added the following else if structure because SFC always uses
 c whole time step
 c
         else if ((time_flag .eq. half_step) .and.
      &           (keywordsave .eq. k_sfcpts)) then
-           write(9,'(A)')
-     &      '  Values on the whole time step will be used.'
+          write(9,'(A)') '  Values on the whole time step will be used.'
         else
-           write(9,'(A)') '  Values on the half time step will be used.'
+          write(9,'(A)') '  Values on the half time step will be used.'
         endif
 c
         tbegout(numout)  = tstart
@@ -937,14 +989,18 @@ c         create label for output
 c
         write (cbranch,'(i2)') nbrns
         iblank_pointer = index(cbranch,' ')
+
         if (iblank_pointer .eq. 1) then
           cbranch = '0' // cbranch(2:2)
         endif
+
         write (cblock,'(i2)')  nublks
         iblank_pointer = index(cblock,' ')
+
         if (iblank_pointer .eq. 1) then
           cblock = '0' // cblock(2:2)
         endif
+
         branch_block = cbranch // cblock
         call strip(labelidr,istart,iend)
         tagout(numout) = labelidr(1:iend) // branch_block
@@ -963,6 +1019,7 @@ c is a comment).
 c
       else if ( (keyword(1:1) .eq. diaglabel_key) .or.
      +          (keyword(1:1) .eq. diaglabel_altkey) ) then
+
         if (lastblk .eq. outputreq) then
 c
 c Strip blanks from contents of currline
@@ -970,23 +1027,28 @@ c Here we want to use currline_lc
 c
           call strip (currline_lc, icl1, icl2)
 c Note currline is *120 not *80
+
           if (icl1 .eq. 80) then
             currline_lc = ' '
             icl1     = 1
           else
             icl1     = icl1 + 1
           end if
+
 c Note currline is *120 not *80
+c Why :80 and not :icl2?
           lblout(numout) = currline_lc(icl1:80)
         else
           continue
         end if
+
 c
 c Label for user variable (if last block was an output request, else it
 c is ignored).
 c
       else if (keyword .eq. k_ulabel) then
 c
+
         if (lastblk .eq. outputreq) then
           il1 = index(currline,'ULABEL')
           currline = currline(il1+7:80)
@@ -997,18 +1059,19 @@ c
         else
           continue
         end if
+
 c
-c Unkown keyword.
+c Unknown keyword.
 c
       else
         call print_bad_line (currline, nlines, numerr)
       end if
+
 c
 c Get another line.
 c
 
-      status=305
+      status = 305
       
       return
       end
-      
