@@ -33,6 +33,8 @@ c                 141-143 so that they are divided by 2.
 c 2019-01-18 RBS: Found and removed the extra 1/16 that replaced the two
 c                 corrected current average 0.5X's in parameter con1.
 c                 Went back to esat = 4e7 to get the losses back up.
+c 2019-01-21 RBS: Removed cup and cdn that were part of the removed
+c                 Zflow routine inputted by Ken Struve.
 c
 c ---------------------------------------------------------------------
 c
@@ -66,7 +68,7 @@ c
       real       circum, gap, tau, rcircum2, rgap, rgap2, eturnon
       real       elec_len, area, elec_area, e1, emp1, v1mv, a1,
      &           zir1, zir2, argp, con2, b1s, bc1s, rbc1s, arg1, g1x,
-     &           fung1,xx, ftail, g1y, cup, cdn, anodeloss, alossden
+     &           fung1, xx, ftail, g1y, anodeloss, alossden
 
       ibranch   = indexmitl(1,index)
       iblock    = indexmitl(2,index)
@@ -243,18 +245,7 @@ c
         anodeloss = anodeloss + v1 * g(node,ibranch)
 c
       end do
-c
-c --- KWS  Zflow Plasma Loss Model ---
-c
-c     Calculate loss current density to the anode for all nodes of the
-c     MITL block, where node1 is the first node in the MITL and
-c     node2 is the last node in the MITL block, depending on tresline
-c     anodeloss is the total current loss over the entire MITL block
-c     Includes charging of the capacitor
-c
-c      cup                    = zir(node1-1,ibranch)
-c      cdn                    = zir(node2  ,ibranch)
-c      anodeloss              = cup - cdn
+
       pin(11,iblock,ibranch) = anodeloss
       alossden               = anodeloss/( area*float(node2-node1+1) )
       pin(10,iblock,ibranch) = alossden
