@@ -22,6 +22,7 @@ c 2015-06-23 RBS: nvar_node initialized
 c 2015-09-25 RBS: Buffer*80 size exceeded in node max check write. That
 c                 write replaced with a direct screen write.
 c 2018-07-20 RBS: Initialized itabnum
+c 2019-11-29 RBS: Added output of node total in the node check section
 c
 c ----------------------------------------------------------------------
 c
@@ -385,6 +386,7 @@ c           call writebuffer(buffer)
            goto 802
            endif
          enddo
+        write(6,'(A,I5/)') '   Total nodes in simulation = ', nbr
   203 format(' Maximum number of nodes exceeded.  Increase',
      &' TL resolution time.'/' Or, recompile with larger',
      &' MAX_NODES parameter in the file zdemmax.h.'/
