@@ -18,11 +18,13 @@ c    2018-07-17 RBS: Changed the version to 4.2.9_beta
 c    2018-07-24 RBS: Changed the version to 4.3
 c    2019-01-28 RBS: Changed the version to 4.3.1
 c    2019-01-28 RBS: Changed the version to 4.3.2
-c    2019-04-28 RBS: Changed the version to 4.3.3
+c    2019-04-23 RBS: Changed the version to 4.3.3
+c    2019-11-25 RBS: Changed the version to 4.4
+c    2019-12-08 RBS: Changed the version to 4.4.1
 c
 c Character strings for SCREAMER version.
 c Edit this string as version changes
 c
       character*(*) screamer_version
       parameter (screamer_version =
-     & 'SCREAMER v4.3.3')
+     & 'SCREAMER v4.4.1_beta')
