@@ -6,8 +6,6 @@ c 2015-06-23 RBS: Placed newfile, oldfile, fflag declarations internal
 c                 removed them from zdemout to get rid of compiler
 c                 warnings.
 c 2016-03-16 RBS: Cleaned up a single write format statement
-
-
 c ----------------------------------------------------------------------
 c
 c Include the files with the various keywords and integer flags.
@@ -38,7 +36,7 @@ c
 
       
 c ----------------------------------------------------------------------
-       write(6,'(A)') 'SCREAMER is now writing to the output file'
+       write(6,'(/A)') 'SCREAMER is now writing to the output file'
  
        if (iset .eq. all_cycles) then
 c
@@ -54,7 +52,7 @@ c
           call tabvals
         end if
 c
-c Create UFO file.
+c Create UFO txt file.
 c
         if (numufo .gt. 0) then
           call ufovals
